import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

from typeguard import check_type

import aws_cdk.aws_applicationautoscaling._jsii
import aws_cdk.aws_autoscaling._jsii
import aws_cdk.aws_certificatemanager._jsii
import aws_cdk.aws_ec2._jsii
import aws_cdk.aws_ecs._jsii
import aws_cdk.aws_elasticloadbalancingv2._jsii
import aws_cdk.aws_events._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_route53._jsii
import aws_cdk.aws_route53_targets._jsii
import aws_cdk.aws_servicediscovery._jsii
import aws_cdk.aws_sqs._jsii
import aws_cdk.core._jsii
import aws_cdk.cx_api._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "@aws-cdk/aws-ecs-patterns",
    "1.185.0",
    __name__[0:-6],
    "aws-ecs-patterns@1.185.0.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
